# 🗃️ dcat-br-ecossistema

[![Python](https://img.shields.io/badge/Python-3.8%2B-blue?logo=python)](https://www.python.org/)
[![Flask](https://img.shields.io/badge/Flask-3.0-blue?logo=flask)](https://flask.palletsprojects.com/)
[![License](https://img.shields.io/badge/License-MIT-green)](LICENSE)

Conjunto de ferramentas oficial para catalogação de conjuntos de dados governamentais brasileiros seguindo o padrão **DCAT-BR**, com geração automática de metadados no padrão DCAT-BR.

![Interface Preview](https://www.gov.br/governodigital/pt-br/infraestrutura-nacional-de-dados/catalogo-nacional-de-dados/catalogo_nacional_de_dados/@@govbr.institucional.banner/b1aa34c9-9395-41d2-8978-21ebb141e44b/@@images/9c458d27-e88b-4978-bd57-b4f5c38880fb.png)

## ✨  Ambiente experimentação - Sandbox

- [dcat-br-ecossistema](https://catalogador-dth.sisp.gov.br/)
- [dcat-br-ecossistema-api-docs](https://catalogador-dth.sisp.gov.br/api/docs/#/)

## 🛠 Funcionalidades

- **Preenchimento Assistido por IA**  
    - 🤖 Agente de IA que auxilia o preenchimento supervisionado de metadados de conjuntos de dados
- **Validação de RDF/XML**  
    - ✅ Verificação de conformidade com DCAT-BR e suporte a URIs e vocabulários controlados
- **Interface Multi-página**
    - 📄 Formulário de catalogação inteligente
    - ⚠️️ Validador de arquivos RDF
    - 📊 Painel de gestão de metadados
- **Arquitetura SOA**  
    - 🌐 Serviços independentes para validação, geração e persistência com APIs com documentação Swagger
- **Exportação Padronizada**
    - 📦 RDF/XML
    - 📦 JSON-LD
    - 📦 CSV para sistemas legados


## ⚡ Instalação Rápida

### Pré-requisitos
- Python 3.10+
- pip
- Chave de API do Google Gemini ([obter chave](https://ai.google.dev/))
- Git (opcional)


### Passo a Passo

**Clonar o repositório**:
```bash
git clone http://git.planejamento.gov.br/sgd_publico/catalogo_nacional_dados.git
cd catalogo_nacional_dados/dcat-br-ecossistema
```

**Criar ambiente virtual:**:
```bash
python -m venv venv-dcat-br-ecossistema 
```

**Ativar ambiente virtual:**
```bash

# Linux/Mac
source venv-dcat-br-ecossistema/bin/activate

# Windows
.\venv-dcat-br-ecossistema\Scripts\activate


```

**Instalar dependências:**:
```bash
pip install -r requirements.txt
```
**Configurar ambiente**
```bash
cp .env.example .env
```
**Editar .env com sua chave da API**
```bash
nano .env
```

**Executar aplicação:**:
```bash
python dcat-br-ecossistema.py
```

**Acessar interface:**:
```bash
http://localhost:5000
```

## ⚡ Como Utilizar

```bash
http://localhost:5000/catalogacao
```

- Preencha o formulário manualmente ou usando o assistente de IA;
- Para campos URI, utilize endereços válidos (ex: http://creativecommons.org/licenses/by/4.0/);
- Separe múltiplos valores (como palavras-chave) por vírgulas;
- Clique em "Gerar RDF" para exportar o arquivo de metadados.

```bash
http://localhost:5000/validacao
```

- Clique no botão 🤖 no formulário;
- Forneça contexto básico;
- Revise e ajuste as sugestões automáticas.


## 🤝 Como Contribuir

- Faça um fork do projeto;
- Crie uma branch para sua feature:

**Feature**:
```bash
git checkout -b feature/nova-feature
```

**Commit suas mudanças**:
```bash
git commit -m 'Adiciona nova funcionalidade'
```

**Push para a branch:**:
```bash
git push origin feature/nova-feature
```

**Abra um Pull Request**:

## 📄 Licença

- Este projeto está licenciado sob a Licença MIT.

## 🌐 Recursos Oficiais

- [Documentação DCAT-BR](https://www.gov.br/governodigital/pt-br/infraestrutura-nacional-de-dados/catalogo-nacional-de-dados/materiais-de-apoio/vocabulario-padrao-dcat-br-v1.0/@@download/file)
- [W3C DCAT](https://www.w3.org/TR/vocab-dcat-3/)

## 👥 Reconhecimentos

- W3C DCAT


