from flask import request, jsonify
from app.services.rdf_generation_service import RDFGenerator
from app.services.rdf_parsing_service import RDFParser
from app.services.validation_service import ValidationService


class DcatController:
    @staticmethod
    def generate_rdf():
        required_fields = ['title', 'description', 'publisher', 'contactPoint', 
                         'license', 'accrualPeriodicity']
        form_data = request.form if request.form else request.get_json()
        
        is_valid, message = ValidationService.validate_form_data(form_data, required_fields)
        if not is_valid:
            return jsonify({"error": message}), 400

        rdf_content = RDFGenerator.generate(form_data)
        return rdf_content, 200, {
            'Content-Type': 'application/rdf+xml',
            'Content-Disposition': 'attachment; filename=metadata.rdf'
        }

    @staticmethod
    def import_rdf():
        if 'rdfFile' not in request.files:
            return jsonify({"error": "Nenhum arquivo enviado"}), 400
            
        file = request.files['rdfFile']
        if not file or file.filename == '':
            return jsonify({"error": "Nome de arquivo inválido"}), 400

        try:
            extracted_data = RDFParser.parse_rdf_file(file.read())
            return jsonify(extracted_data)
        except Exception as e:
            return jsonify({"error": f"Erro ao processar RDF: {str(e)}"}), 400      

    @staticmethod
    def validate_rdf():
        if 'rdfFile' not in request.files:
            return jsonify({"valid": False, "errors": ["Nenhum arquivo enviado"]}), 400
            
        file = request.files['rdfFile']
        if not file or file.filename == '':
            return jsonify({"valid": False, "errors": ["Nome de arquivo inválido"]}), 400

        try:
            is_valid, errors = ValidationService.validate_rdf_file(file.read())
            return jsonify({
                "valid": is_valid,
                "errors": errors
            }), 200 if is_valid else 400

        except Exception as e:
            return jsonify({
                "valid": False,
                "errors": [f"Erro interno: {str(e)}"]
            }), 500