from rdflib import Graph, Namespace
from rdflib.namespace import DCAT, DCTERMS, FOAF, RDF, XSD


ADMS = Namespace("http://www.w3.org/ns/adms#")
DCAT = Namespace("http://www.w3.org/ns/dcat#")
DCAT.license = Namespace("http://purl.org/dc/terms/license")


class RDFParser:
    @staticmethod    
    def parse_rdf_file(file_content):
        g = Graph()
        g.bind("dcat", DCAT)
        g.bind("dcterms", DCTERMS)
        g.parse(data=file_content, format='xml')


        dataset = next(g.subjects(RDF.type, DCAT.Dataset), None)
        if not dataset:
            raise ValueError("Nenhum dataset DCAT encontrado no arquivo")

        creator = g.value(dataset, DCTERMS.creator)
        
        return {
            'title': str(g.value(dataset, DCTERMS.title)),
            'description': str(g.value(dataset, DCTERMS.description)),
            'publisher': str(g.value(dataset, DCTERMS.publisher)),
            'contactPoint': str(g.value(dataset, DCAT.contactPoint)).replace('mailto:', ''),         
            'license': str(g.value(dataset, DCTERMS.license)),            
            'accrualPeriodicity': str(g.value(dataset, DCTERMS.accrualPeriodicity)),
            'accessRights': str(g.value(dataset, DCTERMS.accessRights)),
            'version': str(g.value(dataset, ADMS.version)),
            'keywords': ', '.join(str(k) for k in g.objects(dataset, DCAT.keyword)),
            'theme': ', '.join(str(t) for t in g.objects(dataset, DCAT.theme)),
            'creator': str(g.value(creator, FOAF.name)) if creator else ''
        }
    
