from rdflib import Graph
from rdflib.namespace import DCAT, DCTERMS, FOAF, RDF, XSD
from urllib.parse import urlparse
from flask import jsonify
from jsonschema import validate
from jsonschema.exceptions import ValidationError

class ValidationService:
    @staticmethod
    def validate_form_data(form_data, required_fields):
        errors = []
        # Validação de campos obrigatórios
        for field in required_fields:
            if not form_data.get(field):
                errors.append(f"Campo obrigatório faltando: {field}")

        # Validação de e-mail
        if '@' not in form_data.get('contactPoint', ''):
            errors.append("Formato de e-mail inválido no campo de contato")

        # Validação de URL da licença
        try:
            url = urlparse(form_data['license'])
            if not all([url.scheme, url.netloc]):
                errors.append("URL da licença inválida")
        except:
            errors.append("Erro na análise da URL da licença")

        return len(errors) == 0, errors if errors else "Validação bem-sucedida"

    @staticmethod
    def validate_rdf_file(file_content):
        try:
            g = Graph()
            g.parse(data=file_content, format='xml')
            
            errors = []
            dataset = next(g.subjects(RDF.type, DCAT.Dataset), None)

            # Validação de propriedades obrigatórias DCAT-BR
            required_properties = [
                (DCTERMS.title, "Título"),
                (DCTERMS.description, "Descrição"),
                (DCTERMS.publisher, "Publicador"),
                (DCAT.contactPoint, "Ponto de contato"),
                (DCTERMS.license, "Licença")
            ]

            for prop, name in required_properties:
                if not g.value(dataset, prop):
                    errors.append(f"Propriedade obrigatória ausente: {name} ({prop})")

            # Validação de formato de e-mail
            contact_point = str(g.value(dataset, DCAT.contactPoint))
            if not contact_point.startswith("mailto:") or '@' not in contact_point:
                errors.append("Formato inválido para ponto de contato")

            return True if not errors else False, errors

        except Exception as e:
            return False, [f"Erro na análise do RDF: {str(e)}"]        
