// Validação de formulário
(() => {
    'use strict'
    const forms = document.querySelectorAll('.needs-validation')
    Array.from(forms).forEach(form => {
        form.addEventListener('submit', event => {
            if (!form.checkValidity()) {
                event.preventDefault()
                event.stopPropagation()
            }
            form.classList.add('was-validated')
        }, false)
    })
})()

// Função de importação de RDF
function importRDF() {
    const fileInput = document.getElementById('rdfFile')
    const errorDiv = document.getElementById('importError')
    
    if (!fileInput.files[0]) {
        errorDiv.textContent = "Selecione um arquivo RDF primeiro!"
        return
    }

    const formData = new FormData()
    formData.append('rdfFile', fileInput.files[0])

    fetch('/import_rdf', {
        method: 'POST',
        body: formData
    })
    .then(response => response.json())
    .then(data => {
        if (data.error) {
            errorDiv.textContent = data.error
            return
        }
        
        // Preenche os campos do formulário
        Object.keys(data).forEach(key => {
            const element = document.querySelector(`[name="${key}"]`)
            if (element) element.value = data[key]
        })
        errorDiv.textContent = ""
    })
    .catch(error => {
        errorDiv.textContent = "Erro ao processar o arquivo RDF"
    })
}

function validateRDF() {
    const fileInput = document.getElementById('rdfValidationFile');
    const resultDiv = document.getElementById('validationResult');
    
    if (!fileInput.files[0]) {
        resultDiv.innerHTML = `<div class="alert alert-danger">Selecione um arquivo RDF</div>`;
        return;
    }

    const formData = new FormData();
    formData.append('rdfFile', fileInput.files[0]);

    fetch('/validate_rdf', {
        method: 'POST',
        body: formData
    })
    .then(response => response.json())
    .then(data => {
        if (data.valid) {
            resultDiv.innerHTML = `<div class="alert alert-success">✓ Arquivo válido conforme DCAT-BR</div>`;
        } else {
            const errors = data.errors.map(e => `<li>${e}</li>`).join('');
            resultDiv.innerHTML = `
                <div class="alert alert-danger">
                    <strong>Erros encontrados:</strong>
                    <ul>${errors}</ul>
                </div>
            `;
        }
    })
    .catch(error => {
        resultDiv.innerHTML = `<div class="alert alert-danger">Erro na validação</div>`;
    });
}