function validateRDF() {
    const fileInput = document.getElementById('rdfFile');
    const resultDiv = document.getElementById('validationResult');
    
    if (!fileInput.files[0]) {
        resultDiv.innerHTML = `
            <div class="alert alert-danger">
                <i class="bi bi-exclamation-circle"></i> Selecione um arquivo RDF primeiro!
            </div>`;
        return;
    }

    const formData = new FormData();
    formData.append('rdfFile', fileInput.files[0]);

    resultDiv.innerHTML = `
        <div class="alert alert-info">
            <div class="spinner-border spinner-border-sm" role="status">
                <span class="visually-hidden">Validando...</span>
            </div>
            Validando arquivo...
        </div>`;

    fetch('/validate_rdf', {
        method: 'POST',
        body: formData
    })
    .then(response => response.json())
    .then(data => {
        if (data.valid) {
            resultDiv.innerHTML = `
                <div class="alert alert-success">
                    <i class="bi bi-check-circle"></i> Arquivo válido!
                    <div class="mt-2">O arquivo está em conformidade com o padrão DCAT-BR</div>
                </div>`;
        } else {
            const errors = data.errors.map(e => `
                <li class="list-group-item d-flex justify-content-between align-items-start">
                    <div class="ms-2 me-auto">
                        <div class="fw-bold">${e.split(':')[0]}</div>
                        ${e.split(':')[1] || ''}
                    </div>
                    <span class="badge bg-danger rounded-pill">!</span>
                </li>
            `).join('');

            resultDiv.innerHTML = `
                <div class="alert alert-danger">
                    <h5><i class="bi bi-x-circle"></i> Erros encontrados:</h5>
                    <ul class="list-group mt-3">${errors}</ul>
                </div>`;
        }
    })
    .catch(error => {
        resultDiv.innerHTML = `
            <div class="alert alert-danger">
                <i class="bi bi-x-circle"></i> Erro na validação: ${error.message}
            </div>`;
    });
}